@@ -30,7 +30,7 @@ public:
   virtual const double operator()(const double cvm) const;
      // compute the tail probability for given cvm
 
-  virtual const double operator()(const long Q) const = 0;
+  virtual const double operator()(const int64_t Q) const = 0;
      // compute the tail frequence for given Q
   
 protected:
